==> mm3d_1.3.6.orig.tar.gz: mm3d-1.3.6/src/tools/selectfacetoolwidget.h <==
/*  Misfit Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#ifndef __SELECTFACETOOLWIDGET_H
#define __SELECTFACETOOLWIDGET_H

#include "mq3macro.h"
#include "mq3compat.h"

class QMainWindow;

class QVBoxLayout;
class QHBoxLayout;

class QGroupBox;
class QSpinBox;
class QCheckBox;
class QLabel;

class SelectFaceToolWidget : public QDockWindow
{
   Q_OBJECT

   public:
      class Observer
      {
         public:
            virtual ~Observer() {};
            virtual void setBackfacingValue( bool newValue )  = 0;
      };

      SelectFaceToolWidget( Observer * observer, QWidget * parent );
      virtual ~SelectFaceToolWidget();

   public slots:
      void backfacingValueChanged( bool backfacing );

   protected:
      Observer    * m_observer;

      QBoxLayout * m_layout;

      QGroupBox   * m_groupBox;
      QLabel      * m_backfacingLabel;
      QCheckBox   * m_backfacingValue;
};

#endif // __SELECTFACETOOLWIDGET_H

==> mm3d_1.3.7.orig.tar.gz: mm3d-1.3.7/src/tools/selectfacetoolwidget.h <==
/*  Misfit Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#ifndef __SELECTFACETOOLWIDGET_H
#define __SELECTFACETOOLWIDGET_H

class QMainWindow;

class QVBoxLayout;
class QHBoxLayout;
class QBoxLayout;

class QGroupBox;
class QSpinBox;
class QCheckBox;
class QLabel;

#include "toolwidget.h"

class SelectFaceToolWidget : public ToolWidget
{
   Q_OBJECT

   public:
      class Observer
      {
         public:
            virtual ~Observer() {};
            virtual void setBackfacingValue( bool newValue )  = 0;
      };

      SelectFaceToolWidget( Observer * observer, QMainWindow * parent );
      virtual ~SelectFaceToolWidget();

   public slots:
      void backfacingValueChanged( bool backfacing );

   protected:
      Observer    * m_observer;

      QBoxLayout  * m_layout;

      QGroupBox   * m_groupBox;
      QLabel      * m_backfacingLabel;
      QCheckBox   * m_backfacingValue;
};

#endif // __SELECTFACETOOLWIDGET_H
